##  Overview
After you've configured and activated an integration, you can check the progress and results of synchronizations between the systems in the Synchronization Logging section of the administration area.
To navigate to the section, in the administration area, select Sync Logging in the sidebar.
You can view synchronization logs to ensure that the integration works as expected. If you see errors or warnings, adjust the configuration of the integration. To learn more, see [Troubleshooting Synchronization Issues](https://help.sap.com/docs/leanix/ea/synchronization-logging?locale=en-US&state=PRODUCTION&version=CLOUD#loio275d86a77a4410149a3cc45e299aa022__best_practices).
![Synchronization Logging section showing synchronization runs for all your active integrations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27543ce07a44101481f7d8ee6c9cc51a_LowRes.png)
Synchronization Logging Page in the Administration Area
